@@ -1,15 +1,16 @@
 package client
 
-import (
-	"github.com/goreleaser/goreleaser/pkg/config"
-)
+import "github.com/goreleaser/goreleaser/pkg/config"
 
 // RepoFromRef converts a config.RepoRef into a Repo.
 func RepoFromRef(ref config.RepoRef) Repo {
 	return Repo{
-		Owner:  ref.Owner,
-		Name:   ref.Name,
-		Branch: ref.Branch,
+		Owner:         ref.Owner,
+		Name:          ref.Name,
+		Branch:        ref.Branch,
+		GitURL:        ref.Git.URL,
+		GitSSHCommand: ref.Git.SSHCommand,
+		PrivateKey:    ref.Git.PrivateKey,
 	}
 }
 
@@ -27,11 +28,24 @@ func TemplateRef(apply func(s string) (string, error), ref config.RepoRef) (conf
 	if err != nil {
 		return ref, err
 	}
+	gitURL, err := apply(ref.Git.URL)
+	if err != nil {
+		return ref, err
+	}
+	privateKey, err := apply(ref.Git.PrivateKey)
+	if err != nil {
+		return ref, err
+	}
 	return config.RepoRef{
 		Owner:       owner,
 		Name:        name,
 		Token:       ref.Token,
 		Branch:      branch,
 		PullRequest: ref.PullRequest,
+		Git: config.GitRepoRef{
+			URL:        gitURL,
+			PrivateKey: privateKey,
+			SSHCommand: ref.Git.SSHCommand,
+		},
 	}, nil
 }
