@@ -58,7 +58,7 @@ func TestClient_Share(t *testing.T) {
 	server := httptest.NewServer(http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
 		_, _ = io.WriteString(rw, `
 {
-	"id": "foo",
+	"sub": "foo",
 	"activity": "123456789"
 }
 `)
@@ -83,3 +83,38 @@ func TestClient_Share(t *testing.T) {
 	wantLink := "https://www.linkedin.com/feed/update/123456789"
 	require.Equal(t, wantLink, link)
 }
+
+func TestClientLegacyProfile_Share(t *testing.T) {
+	server := httptest.NewServer(http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
+		if req.URL.Path == "/v2/userinfo" {
+			rw.WriteHeader(http.StatusForbidden)
+			return
+		}
+		// this is the response from /v2/me (legacy as a fallback)
+		_, _ = io.WriteString(rw, `
+		{
+			"id": "foo",
+			"activity": "123456789"
+		}
+		`)
+	}))
+	defer server.Close()
+
+	c, err := createLinkedInClient(oauthClientConfig{
+		Context:     testctx.New(),
+		AccessToken: "foo",
+	})
+	if err != nil {
+		t.Fatalf("could not create client: %v", err)
+	}
+
+	c.baseURL = server.URL
+
+	link, err := c.Share("test")
+	if err != nil {
+		t.Fatalf("could not share: %v", err)
+	}
+
+	wantLink := "https://www.linkedin.com/feed/update/123456789"
+	require.Equal(t, wantLink, link)
+}
