@@ -3,22 +3,24 @@ package release
 import (
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/git"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
 func TestSetupGitLab(t *testing.T) {
 	t.Run("no repo", func(t *testing.T) {
-		ctx := context.New(config.Project{})
-
+		ctx := testctx.New()
 		require.NoError(t, setupGitLab(ctx))
-		require.Equal(t, "goreleaser", ctx.Config.Release.GitLab.Owner)
-		require.Equal(t, "goreleaser", ctx.Config.Release.GitLab.Name)
+		repo, err := git.ExtractRepoFromConfig(ctx)
+		require.NoError(t, err)
+		require.Equal(t, repo.Owner, ctx.Config.Release.GitLab.Owner)
+		require.Equal(t, repo.Name, ctx.Config.Release.GitLab.Name)
 	})
 
 	t.Run("with templates", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Env: []string{"NAME=foo", "OWNER=bar"},
 			GitLabURLs: config.GitLabURLs{
 				Download: "https://{{ .Env.OWNER }}/download",
@@ -39,7 +41,7 @@ func TestSetupGitLab(t *testing.T) {
 
 	t.Run("with invalid templates", func(t *testing.T) {
 		t.Run("owner", func(t *testing.T) {
-			ctx := context.New(config.Project{
+			ctx := testctx.NewWithCfg(config.Project{
 				Release: config.Release{
 					GitLab: config.Repo{
 						Name:  "foo",
@@ -52,7 +54,7 @@ func TestSetupGitLab(t *testing.T) {
 		})
 
 		t.Run("name", func(t *testing.T) {
-			ctx := context.New(config.Project{
+			ctx := testctx.NewWithCfg(config.Project{
 				Release: config.Release{
 					GitLab: config.Repo{
 						Name: "{{.Env.NOPE}}",
@@ -67,15 +69,14 @@ func TestSetupGitLab(t *testing.T) {
 
 func TestSetupGitea(t *testing.T) {
 	t.Run("no repo", func(t *testing.T) {
-		ctx := context.New(config.Project{})
-
+		ctx := testctx.New()
 		require.NoError(t, setupGitea(ctx))
 		require.Equal(t, "goreleaser", ctx.Config.Release.Gitea.Owner)
 		require.Equal(t, "goreleaser", ctx.Config.Release.Gitea.Name)
 	})
 
 	t.Run("with templates", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Env: []string{"NAME=foo", "OWNER=bar"},
 			GiteaURLs: config.GiteaURLs{
 				Download: "https://{{ .Env.OWNER }}/download",
@@ -96,7 +97,7 @@ func TestSetupGitea(t *testing.T) {
 
 	t.Run("with invalid templates", func(t *testing.T) {
 		t.Run("owner", func(t *testing.T) {
-			ctx := context.New(config.Project{
+			ctx := testctx.NewWithCfg(config.Project{
 				Release: config.Release{
 					Gitea: config.Repo{
 						Name:  "foo",
@@ -109,7 +110,7 @@ func TestSetupGitea(t *testing.T) {
 		})
 
 		t.Run("name", func(t *testing.T) {
-			ctx := context.New(config.Project{
+			ctx := testctx.NewWithCfg(config.Project{
 				Release: config.Release{
 					Gitea: config.Repo{
 						Name: "{{.Env.NOPE}}",
@@ -124,15 +125,14 @@ func TestSetupGitea(t *testing.T) {
 
 func TestSetupGitHub(t *testing.T) {
 	t.Run("no repo", func(t *testing.T) {
-		ctx := context.New(config.Project{})
-
+		ctx := testctx.New()
 		require.NoError(t, setupGitHub(ctx))
 		require.Equal(t, "goreleaser", ctx.Config.Release.GitHub.Owner)
 		require.Equal(t, "goreleaser", ctx.Config.Release.GitHub.Name)
 	})
 
 	t.Run("with templates", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Env: []string{"NAME=foo", "OWNER=bar"},
 			GitHubURLs: config.GitHubURLs{
 				Download: "https://{{ .Env.OWNER }}/download",
@@ -153,7 +153,7 @@ func TestSetupGitHub(t *testing.T) {
 
 	t.Run("with invalid templates", func(t *testing.T) {
 		t.Run("owner", func(t *testing.T) {
-			ctx := context.New(config.Project{
+			ctx := testctx.NewWithCfg(config.Project{
 				Release: config.Release{
 					GitHub: config.Repo{
 						Name:  "foo",
@@ -166,7 +166,7 @@ func TestSetupGitHub(t *testing.T) {
 		})
 
 		t.Run("name", func(t *testing.T) {
-			ctx := context.New(config.Project{
+			ctx := testctx.NewWithCfg(config.Project{
 				Release: config.Release{
 					GitHub: config.Repo{
 						Name: "{{.Env.NOPE}}",
